Learn R Programming

ValidationExplorer (version 0.1.1)

make_not_confirmable: Further masking of true species labels to mimic whether a recording is confirmable

Description

Further masking of true species labels to mimic whether a recording is confirmable

Usage

make_not_confirmable(masked_df, confirmable_limits)

Arguments

Value

A copy of the original dataframe, with some selected observations masked because they could not be confirmed.