powered by
Draws from an MCMC algorithm fit to simulated data. This object exists solely for easing examples in documentation of mcmc_sum.
A list of length 3 matrices with columns and rows as described here.
Columns: Parameters (lambda, psi, and theta for a two species assemblage)
Rows; Iterations of the MCMC. There are 1000 post-warmup draws for each.
str(ValExp_example_fit)
Run the code above in your browser using DataLab