Learn R Programming

ValidationExplorer (version 0.1.1)

example_output: example_output

Description

A dataframe in the format output from running run_sims. This exists solely for the purpose of making documentation of visualization functions easier.

  • parameter. Parameters (lambda, psi, and theta for a two species assemblage).

  • Mean. The posterior mean.

  • SD. The standard deviation of the draws of reach parameter.

  • Naive SE. The standard error, not accounting for the correlation in draws

  • Time-series SE. The standard error, accounting for correlation in draws.

  • quantiles. 2.5%, 25%, 50%, 75% and 97.5% quantiles.

  • Rhat. The Gelman-Rubin statistic for each parameter.

  • ess_bulk. The effective sample size in the bulk of the distribution.

  • ess_tail. The effective sample size in the tails of the distribution.

  • truth. The known true data generating value.

  • capture. Did the 95% posterior interval contain the true value?

  • converge. Was the Gelman-Rubin statistic near 1?

  • theta_scenario. The ID for the classifier scenario.

  • scenario. The index of the validation scenario.

  • dataset. The dataset index.

Arguments

Format

A dataframe containing the columns described below.

Examples

Run this code

head(example_output)

visualize_parameter_group(
  example_output,
  pars = "lambda",
  theta_scenario = "1",
  scenarios = 1:2
)

Run the code above in your browser using DataLab