powered by
See detailed simulation study results for a parameter of interest
visualize_single_parameter( sim_summary, par, theta_scenario, scenarios, convergence_threshold = 1.1 )
A ggplot object summarizing simulation results.
Summary output in the format of run_sims.
The parameter to be visualized.
The theta scenario IDs. This should match the theta_scenario_id argument ofrun_sims().
theta_scenario_id
run_sims()
Scenarios to be visualized.
If the Gelman-Rubin statistic is below this value, consider an MCMC to have converged. Default value is 1.1, but we recommend 1.05.
visualize_single_parameter( example_output, par = "lambda[1]", theta_scenario = "1", scenarios = 1:2, convergence_threshold = 1.05 )
Run the code above in your browser using DataLab